@@ -1,5 +1,5 @@
 from StreamAnalyzer import StreamAnalyzer
-from PyQt4 import QtCore
+from PySide import QtCore
 
 import gobject
 import time
