@@ -6,10 +6,18 @@ from urllib2 import install_opener
 import time
 
 import crypt
+import keys
+import sys
 
 def _inttime():
         return int( time.time() )
 
+class PandoraError(Exception):
+	def __init__( self, value ):
+		self.value = value
+	def __str__( self ):
+		return repr( self.value )
+
 class Pandora:
         rid = ""
         lid = ""
@@ -17,7 +25,7 @@ class Pandora:
         curStation = ""
         curFormat = "mp3" #Default to mp3 if not specified
         protocol_version=31
-        base_url = "http://www.pandora.com/radio/xmlrpc/v%d?" %protocol_version
+        base_url = "https://www.pandora.com/radio/xmlrpc/v%d?" %protocol_version
         base_url_rid = base_url + "rid=%sP&method=%s"
         base_url_lid = base_url + "rid=%sP&lid=%s&method=%s"
         proxy = ""
@@ -29,9 +37,13 @@ class Pandora:
                 self.rid = "%07i" %( time.time() % 10000000 )
                 if pv > self.protocol_version:
                     self.protocol_version=pv
-                self.base_url = "http://www.pandora.com/radio/xmlrpc/v%d?" %(self.protocol_version)
+		self.dataDir = sys.path[0]+"/libpiano/"
+                self.base_url = "https://www.pandora.com/radio/xmlrpc/v%d?" %(self.protocol_version)
                 self.base_url_rid = self.base_url + "rid=%sP&method=%s"
                 self.base_url_lid = self.base_url + "rid=%sP&lid=%s&method=%s"
+		self.keys = keys.Keys( self.dataDir, self.protocol_version )
+		if not self.keys.loadKeys():
+			raise PandoraError("Unable to load Keys");
                 self.curFormat = format
 
         def set_proxy( self, proxy ):
@@ -62,7 +74,7 @@ class Pandora:
                         req = xmlrpclib.dumps( ( _inttime(), user, pwd ), \
                                                 "listener.authenticateListener" )
                         req = req.replace( "\n", "" )
-                        enc = crypt.encryptString( req )
+                        enc = crypt.encryptString( req, self.keys['out'] )
                         try:
                                 u = urlopen( reqUrl, enc )
                                 resp = u.read()
@@ -70,7 +82,7 @@ class Pandora:
                                     new_version = new_version+1
                                     if new_version - self.protocol_version < 15:
                                             print "INCOMPATIBLE VERSION DETECTED, BUMPING."
-                                            self.base_url = "http://www.pandora.com/radio/xmlrpc/v%d?" %(new_version)
+                                            self.base_url = "https://www.pandora.com/radio/xmlrpc/v%d?" %(new_version)
                                             self.base_url_rid = self.base_url + "rid=%sP&method=%s"
                                             self.base_url_lid = self.base_url + "rid=%sP&lid=%s&method=%s"
                                             continue
@@ -97,7 +109,7 @@ class Pandora:
                 req = xmlrpclib.dumps( ( _inttime(), self.authToken ), \
                                                                 "station.getStations" )
                 req = req.replace( "\n", "" )
-                enc = crypt.encryptString( req )
+                enc = crypt.encryptString( req, self.keys['out'] )
 
                 u = urlopen( reqUrl, enc )
                 resp = u.read()
@@ -127,7 +139,7 @@ class Pandora:
 
                 req = xmlrpclib.dumps( args, "station.addFeedback" )
                 req = req.replace( "\n", "" )
-                enc = crypt.encryptString( req )
+                enc = crypt.encryptString( req, self.keys['out'] )
 
                 u = urlopen( reqUrl, enc )
                 resp = u.read()
@@ -155,7 +167,7 @@ class Pandora:
                 req = xmlrpclib.dumps( args, "station.addSeed" )
 
                 req = req.replace( "\n", "" )
-                enc = crypt.encryptString( req )
+                enc = crypt.encryptString( req, self.keys['out'] )
 
                 u = urlopen( reqUrl, enc )
                 resp = u.read()
@@ -180,7 +192,7 @@ class Pandora:
 
                 req = xmlrpclib.dumps( args, "listener.addTiredSong" )
                 req = req.replace( "\n", "" )
-                enc = crypt.encryptString( req )
+                enc = crypt.encryptString( req, self.keys['out'] )
 
                 u = urlopen( reqUrl, enc )
                 resp = u.read()
@@ -205,7 +217,7 @@ class Pandora:
 
                 req = xmlrpclib.dumps( args, "music.search" )
                 req = req.replace( "\n", "" )
-                enc = crypt.encryptString( req )
+                enc = crypt.encryptString( req, self.keys['out'] )
 
                 u = urlopen( reqUrl, enc )
                 resp = u.read()
@@ -230,7 +242,7 @@ class Pandora:
 
                 req = xmlrpclib.dumps( args, "station.createStation" )
                 req = req.replace( "\n", "" )
-                enc = crypt.encryptString( req )
+                enc = crypt.encryptString( req, self.keys['out'] )
 
                 u = urlopen( reqUrl, enc )
                 resp = u.read()
@@ -255,7 +267,7 @@ class Pandora:
 
                 req = xmlrpclib.dumps( args, "station.removeStation" )
                 req = req.replace( "\n", "" )
-                enc = crypt.encryptString( req )
+                enc = crypt.encryptString( req, self.keys['out'] )
 
                 u = urlopen( reqUrl, enc )
                 resp = u.read()
@@ -281,7 +293,7 @@ class Pandora:
                                         format, "0", "0" )
                 req = xmlrpclib.dumps( args, "playlist.getFragment" )
                 req = req.replace( "\n", "" )
-                enc = crypt.encryptString( req )
+                enc = crypt.encryptString( req, self.keys['out'] )
 
                 u = urlopen( reqUrl, enc )
                 resp = u.read()
@@ -297,7 +309,7 @@ class Pandora:
                 #last 48 chars of URL encrypted, padded w/ 8 * '\x08'
                 for i in range( len( parsed ) ):
                         url = parsed[i]["audioURL"]
-                        url = url[:-48] + crypt.decryptString( url[-48:] )[:-8]
+                        url = url[:-48] + crypt.decryptString( url[-48:], self.keys['in'] )[:-8]
                         parsed[i]["audioURL"] = url
 
                 self.curStation = stationId
