@@ -21,10 +21,8 @@ class RadioPlayer(QtCore.QThread): #Main radio class
 			from libpiano.OSSOBackend import OSSOBackend
 			self.player = OSSOBackend()
 		else:
-			#from libpiano.MPlayerBackend import MPlayerBackend
-			#self.player = MPlayerBackend()
-			from libpiano.OSSOBackend import OSSOBackend
-			self.player = OSSOBackend()
+			from libpiano.GstBackend import GstBackend
+			self.player = GstBackend()
 
 		QtCore.QObject.connect(self.player, QtCore.SIGNAL("eof"), self.sigEOF)
 		QtCore.QObject.connect(self.player, QtCore.SIGNAL("state_change(int)"), self.stateChange)
